==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/OutboundTrafficPolicyFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OutboundTrafficPolicyFluentImpl<A extends OutboundTrafficPolicyFluent<A>> extends BaseFluent<A> implements OutboundTrafficPolicyFluent<A>{
  public OutboundTrafficPolicyFluentImpl() {
  }
  public OutboundTrafficPolicyFluentImpl(OutboundTrafficPolicy instance) {
    this.withEgressProxy(instance.getEgressProxy()); 
    this.withMode(instance.getMode()); 
  }
  private DestinationBuilder egressProxy;
  private OutboundTrafficPolicyMode mode;
  
  /**
   * This method has been deprecated, please use method buildEgressProxy instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getEgressProxy() {
    return this.egressProxy!=null ?this.egressProxy.build():null;
  }
  public Destination buildEgressProxy() {
    return this.egressProxy!=null ?this.egressProxy.build():null;
  }
  public A withEgressProxy(Destination egressProxy) {
    _visitables.get("egressProxy").remove(this.egressProxy);
    if (egressProxy!=null){ this.egressProxy= new DestinationBuilder(egressProxy); _visitables.get("egressProxy").add(this.egressProxy);} else { this.egressProxy = null; _visitables.get("egressProxy").remove(this.egressProxy); } return (A) this;
  }
  public Boolean hasEgressProxy() {
    return this.egressProxy != null;
  }
  public OutboundTrafficPolicyFluent.EgressProxyNested<A> withNewEgressProxy() {
    return new OutboundTrafficPolicyFluentImpl.EgressProxyNestedImpl();
  }
  public OutboundTrafficPolicyFluent.EgressProxyNested<A> withNewEgressProxyLike(Destination item) {
    return new OutboundTrafficPolicyFluentImpl.EgressProxyNestedImpl(item);
  }
  public OutboundTrafficPolicyFluent.EgressProxyNested<A> editEgressProxy() {
    return withNewEgressProxyLike(getEgressProxy());
  }
  public OutboundTrafficPolicyFluent.EgressProxyNested<A> editOrNewEgressProxy() {
    return withNewEgressProxyLike(getEgressProxy() != null ? getEgressProxy(): new DestinationBuilder().build());
  }
  public OutboundTrafficPolicyFluent.EgressProxyNested<A> editOrNewEgressProxyLike(Destination item) {
    return withNewEgressProxyLike(getEgressProxy() != null ? getEgressProxy(): item);
  }
  public OutboundTrafficPolicyMode getMode() {
    return this.mode;
  }
  public A withMode(OutboundTrafficPolicyMode mode) {
    this.mode=mode; return (A) this;
  }
  public Boolean hasMode() {
    return this.mode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OutboundTrafficPolicyFluentImpl that = (OutboundTrafficPolicyFluentImpl) o;
    if (egressProxy != null ? !egressProxy.equals(that.egressProxy) :that.egressProxy != null) return false;
    if (mode != null ? !mode.equals(that.mode) :that.mode != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(egressProxy,  mode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (egressProxy != null) { sb.append("egressProxy:"); sb.append(egressProxy + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode); }
    sb.append("}");
    return sb.toString();
  }
  class EgressProxyNestedImpl<N> extends DestinationFluentImpl<OutboundTrafficPolicyFluent.EgressProxyNested<N>> implements OutboundTrafficPolicyFluent.EgressProxyNested<N>,Nested<N>{
    EgressProxyNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    EgressProxyNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) OutboundTrafficPolicyFluentImpl.this.withEgressProxy(builder.build());
    }
    public N endEgressProxy() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/OutboundTrafficPolicyFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OutboundTrafficPolicyFluentImpl<A extends OutboundTrafficPolicyFluent<A>> extends BaseFluent<A> implements OutboundTrafficPolicyFluent<A>{
  public OutboundTrafficPolicyFluentImpl() {
  }
  public OutboundTrafficPolicyFluentImpl(OutboundTrafficPolicy instance) {
    if (instance != null) {
      this.withEgressProxy(instance.getEgressProxy());
      this.withMode(instance.getMode());
    }
  }
  private DestinationBuilder egressProxy;
  private OutboundTrafficPolicyMode mode;
  
  /**
   * This method has been deprecated, please use method buildEgressProxy instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getEgressProxy() {
    return this.egressProxy!=null ?this.egressProxy.build():null;
  }
  public Destination buildEgressProxy() {
    return this.egressProxy!=null ?this.egressProxy.build():null;
  }
  public A withEgressProxy(Destination egressProxy) {
    _visitables.get("egressProxy").remove(this.egressProxy);
    if (egressProxy!=null){ this.egressProxy= new DestinationBuilder(egressProxy); _visitables.get("egressProxy").add(this.egressProxy);} else { this.egressProxy = null; _visitables.get("egressProxy").remove(this.egressProxy); } return (A) this;
  }
  public Boolean hasEgressProxy() {
    return this.egressProxy != null;
  }
  public OutboundTrafficPolicyFluentImpl.EgressProxyNested<A> withNewEgressProxy() {
    return new OutboundTrafficPolicyFluentImpl.EgressProxyNestedImpl();
  }
  public OutboundTrafficPolicyFluentImpl.EgressProxyNested<A> withNewEgressProxyLike(Destination item) {
    return new OutboundTrafficPolicyFluentImpl.EgressProxyNestedImpl(item);
  }
  public OutboundTrafficPolicyFluentImpl.EgressProxyNested<A> editEgressProxy() {
    return withNewEgressProxyLike(getEgressProxy());
  }
  public OutboundTrafficPolicyFluentImpl.EgressProxyNested<A> editOrNewEgressProxy() {
    return withNewEgressProxyLike(getEgressProxy() != null ? getEgressProxy(): new DestinationBuilder().build());
  }
  public OutboundTrafficPolicyFluentImpl.EgressProxyNested<A> editOrNewEgressProxyLike(Destination item) {
    return withNewEgressProxyLike(getEgressProxy() != null ? getEgressProxy(): item);
  }
  public OutboundTrafficPolicyMode getMode() {
    return this.mode;
  }
  public A withMode(OutboundTrafficPolicyMode mode) {
    this.mode=mode; return (A) this;
  }
  public Boolean hasMode() {
    return this.mode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OutboundTrafficPolicyFluentImpl that = (OutboundTrafficPolicyFluentImpl) o;
    if (!java.util.Objects.equals(egressProxy, that.egressProxy)) return false;

    if (!java.util.Objects.equals(mode, that.mode)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(egressProxy,  mode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (egressProxy != null) { sb.append("egressProxy:"); sb.append(egressProxy + ","); }
    if (mode != null) { sb.append("mode:"); sb.append(mode); }
    sb.append("}");
    return sb.toString();
  }
  class EgressProxyNestedImpl<N> extends DestinationFluentImpl<OutboundTrafficPolicyFluentImpl.EgressProxyNested<N>> implements OutboundTrafficPolicyFluentImpl.EgressProxyNested<N>,Nested<N>{
    EgressProxyNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    EgressProxyNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) OutboundTrafficPolicyFluentImpl.this.withEgressProxy(builder.build());
    }
    public N endEgressProxy() {
      return and();
    }
    
  }
  
}
